==> haskell-authenticate-1.3.5.2-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-CxgwpxSK7UNBAOJBvzqxVW
key:                  authenticate-1.3.5.2-CxgwpxSK7UNBAOJBvzqxVW
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  8b81fff46c6b5bebda051f1a535ebcf2
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-CxgwpxSK7UNBAOJBvzqxVW
depends:
    aeson-2.1.2.1-9cB9LJUUgPXJU8E7LnOs6Q
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK
    attoparsec-aeson-2.1.0.0-IJnRK6lf1vJ98IPCeLjg3m base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER
    conduit-1.3.5-HJrPb2gizae6YrSJmqHmw4 containers-0.6.5.1
    html-conduit-1.3.2.2-8nKrBB7PgO2FAREIEvogFT
    http-conduit-2.3.8.3-FHKEFI1htvQ2IgqoPxTHYO
    http-types-0.12.4-KywvdcgYD9RAReIdCAotLp
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL
    resourcet-1.2.6-AkuAfAqfUrLC3kiGqtKSRc text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-51DmuLN2CgdLFo3pmQx1qE
    xml-conduit-1.9.1.3-R5Tx3qQz1KE95GYqBKeNN

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-Got5Jinx7h0Dw78h3J6yR7
key:                  authenticate-1.3.5.2-Got5Jinx7h0Dw78h3J6yR7
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  dc3a1a10a3f8effad0dcba20706330af
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-Got5Jinx7h0Dw78h3J6yR7
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK
    attoparsec-aeson-2.1.0.0-AqMCU4b5RH2aSl61HEhKB base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER
    conduit-1.3.5-7HSqKM5SWt3UpRibGqqjq containers-0.6.5.1
    html-conduit-1.3.2.2-5LSxigSPrzqJsb4tiEAsea
    http-conduit-2.3.8.3-HdHnSPujvRhClupsH9OiA1
    http-types-0.12.4-BHydc54DAW314d9zE8t9hR
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL
    resourcet-1.2.6-AkuAfAqfUrLC3kiGqtKSRc text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    xml-conduit-1.9.1.3-EZ6ANdSJD1O1xgN6ayPuaM

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
